agentle.agents.a2a.tasks.task\_get\_result
==========================================

.. automodule:: agentle.agents.a2a.tasks.task_get_result

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      BaseModel
      Task
      TaskGetResult
   